@@ -1,10 +1,7 @@
-/* tilde.h: Externally available variables and function in libtilde.a.
-   $Id: tilde.h 5191 2013-02-23 00:11:18Z karl $
+/* tilde.h: tilde expansion.
+   $Id: tilde.h 5337 2013-08-22 17:54:06Z karl $
 
-   This file has appeared in prior works by the Free Software Foundation;
-   thus it carries copyright dates from 1988 through 1993.
-
-   Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 2004, 2007
+   Copyright 1988, 1989, 1990, 1991, 1992, 1993, 2004, 2007, 2013
    Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -20,7 +17,7 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-   Written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox (for bash). */
 
 #ifndef TILDE_H
 #define TILDE_H
@@ -48,6 +45,6 @@ extern char *tilde_expand (char *string);
 
 /* Do the work of tilde expansion on FILENAME.  FILENAME starts with a
    tilde.  If there is no expansion, call tilde_expansion_failure_hook. */
-extern char *tilde_expand_word (char *filename);
+extern char *tilde_expand_word (const char *filename);
 
 #endif /* not TILDE_H */
