@@ -259,32 +259,13 @@ $result_trees{'nested_multitable'} = {
                         'prototypes' => [
                           {
                             'contents' => [],
-                            'parent' => {},
                             'type' => 'bracketed_multitable_prototype'
                           },
                           {
                             'contents' => [],
-                            'parent' => {},
                             'type' => 'bracketed_multitable_prototype'
                           }
                         ],
-                        'prototypes_line' => [
-                          {
-                            'text' => ' ',
-                            'type' => 'prototype_space'
-                          },
-                          {},
-                          {
-                            'text' => ' ',
-                            'type' => 'prototype_space'
-                          },
-                          {},
-                          {
-                            'text' => '
-',
-                            'type' => 'prototype_space'
-                          }
-                        ],
                         'spaces_after_command' => {}
                       },
                       'line_nr' => {
@@ -476,32 +457,13 @@ $result_trees{'nested_multitable'} = {
         'prototypes' => [
           {
             'contents' => [],
-            'parent' => {},
             'type' => 'bracketed_multitable_prototype'
           },
           {
             'contents' => [],
-            'parent' => {},
             'type' => 'bracketed_multitable_prototype'
           }
         ],
-        'prototypes_line' => [
-          {
-            'text' => ' ',
-            'type' => 'prototype_space'
-          },
-          {},
-          {
-            'text' => '    ',
-            'type' => 'prototype_space'
-          },
-          {},
-          {
-            'text' => '
-',
-            'type' => 'prototype_space'
-          }
-        ],
         'spaces_after_command' => {}
       },
       'line_nr' => {
@@ -562,11 +524,7 @@ $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{
 $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1];
 $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[1];
 $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'extra'}{'prototypes'}[0]{'contents'} = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'contents'};
-$result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'extra'}{'prototypes'}[0]{'parent'} = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'extra'}{'prototypes'}[1]{'contents'} = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[3]{'contents'};
-$result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'extra'}{'prototypes'}[1]{'parent'} = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'extra'}{'prototypes_line'}[1] = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'extra'}{'prototypes_line'}[3] = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[3];
 $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0];
@@ -604,11 +562,7 @@ $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[1]{'extra'}{'space
 $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nested_multitable'}{'contents'}[1];
 $result_trees{'nested_multitable'}{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'nested_multitable'}{'contents'}[1]{'contents'}[1];
 $result_trees{'nested_multitable'}{'contents'}[1]{'extra'}{'prototypes'}[0]{'contents'} = $result_trees{'nested_multitable'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'contents'};
-$result_trees{'nested_multitable'}{'contents'}[1]{'extra'}{'prototypes'}[0]{'parent'} = $result_trees{'nested_multitable'}{'contents'}[1]{'args'}[0];
 $result_trees{'nested_multitable'}{'contents'}[1]{'extra'}{'prototypes'}[1]{'contents'} = $result_trees{'nested_multitable'}{'contents'}[1]{'args'}[0]{'contents'}[3]{'contents'};
-$result_trees{'nested_multitable'}{'contents'}[1]{'extra'}{'prototypes'}[1]{'parent'} = $result_trees{'nested_multitable'}{'contents'}[1]{'args'}[0];
-$result_trees{'nested_multitable'}{'contents'}[1]{'extra'}{'prototypes_line'}[1] = $result_trees{'nested_multitable'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'nested_multitable'}{'contents'}[1]{'extra'}{'prototypes_line'}[3] = $result_trees{'nested_multitable'}{'contents'}[1]{'args'}[0]{'contents'}[3];
 $result_trees{'nested_multitable'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'nested_multitable'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'nested_multitable'}{'contents'}[1]{'parent'} = $result_trees{'nested_multitable'};
 
